@@ -1,8 +1,10 @@
 import PIL
 import pygame
-import py2app
 import pydoc
-import pyobjc
 import docutils
 import sip
 import pyopengl
+
+import numpy
+import scipy
+import matplotlib
